package com.jiuqi.office.excel;

import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import java.io.IOException;
import java.util.Map;
import java.io.OutputStream;
import java.util.HashMap;
import com.jiuqi.grid.GridData;

public class SimpleExportor
{
    public static final int EXPORT_MODE_2003 = 0;
    public static final int EXPORT_MODE_2007_LATER = 1;
    public static final int EXPORT_MODE_2007_LATER_SUPER = 2;
    private boolean autoAdjust;
    private boolean addTitle;
    private String title;
    private GridData reportData;
    private HashMap cellStyleHashMap;
    private int transparentColor;
    private boolean doNotCheckNumberIsNull;
    private HashMap HSSFFontMap;
    private String preSheetName;
    public static final int DEFAULT_EXPORT_MODE = 0;
    public static final int MAX_ROW = 65536;
    
    public SimpleExportor(final GridData gridData) {
        this(null, gridData);
    }
    
    public SimpleExportor(final String title, final GridData gridData) {
        this.reportData = (GridData)gridData.clone();
        this.title = title;
        this.cellStyleHashMap = new HashMap();
        this.HSSFFontMap = new HashMap();
        this.transparentColor = -16777201;
        this.doNotCheckNumberIsNull = false;
        this.preSheetName = "Sheet";
        this.addTitle = (title != null);
    }
    
    public void setAutoAdjust(final boolean autoAdjust) {
        this.autoAdjust = autoAdjust;
    }
    
    public void setAddTitle(final boolean addTitle) {
        this.addTitle = addTitle;
    }
    
    public boolean isAutoAdjust() {
        return this.autoAdjust;
    }
    
    public boolean isAddTitle() {
        return this.addTitle;
    }
    
    public void setTitle(final String title) {
        this.title = title;
    }
    
    public void setTransparentColor(final int transparentColor) {
        this.transparentColor = transparentColor;
    }
    
    public boolean isDoNotCheckNumberIsNull() {
        return this.doNotCheckNumberIsNull;
    }
    
    public void setDoNotCheckNumberIsNull(final boolean doNotCheckNumberIsNull) {
        this.doNotCheckNumberIsNull = doNotCheckNumberIsNull;
    }
    
    public String getPreSheetName() {
        return this.preSheetName;
    }
    
    public void setPreSheetName(final String preSheetName) {
        this.preSheetName = preSheetName;
    }
    
    public void export(final OutputStream outStream) throws ExcelException {
        this.export(outStream, 0);
    }
    
    public void export(final OutputStream outStream, final int mode) throws ExcelException {
        if (mode == 0 && this.reportData != null && this.reportData.getRowCount() > 65536) {
            this.exportHSSFWorkbook(outStream);
            return;
        }
        final Workbook wb = this.createWorkbook(mode);
        final Sheet sheet = wb.createSheet(String.valueOf(this.preSheetName) + 0);
        this.cellStyleHashMap.clear();
        final WorksheetWriter sheetWriter = new WorksheetWriter(wb, sheet, this.reportData, this.cellStyleHashMap);
        sheetWriter.setPreSheetName(this.preSheetName);
        sheetWriter.setHSSFFontMap(this.HSSFFontMap);
        sheetWriter.setAddTitle(this.addTitle);
        sheetWriter.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
        if (this.addTitle) {
            sheetWriter.setTitle(this.title);
        }
        sheetWriter.setAutoAdjust(this.autoAdjust);
        sheetWriter.setTransparentColor(this.transparentColor);
        sheetWriter.writeWorkSheet();
        try {
            wb.write(outStream);
        }
        catch (final IOException e) {
            throw new ExcelException(e);
        }
    }
    
    private void exportHSSFWorkbook(final OutputStream outStream) throws ExcelException {
        final int oldRowCountPerPage = this.reportData.getRowCountPerPage();
        final int localBottomRow = this.reportData.getScrollBottomRow();
        final int localTopRow = this.reportData.getScrollTopRow();
        this.reportData.setScrollBottomRow(-1);
        this.reportData.setScrollTopRow(-1);
        this.reportData.setRowCountPerPage(65536);
        final int rowPageCount = this.reportData.getRowPageCount();
        final GridIterator gridIterator = new GridIterator() {
            int sheetIndex = 0;
            
            public boolean next() throws ExcelException {
                return this.sheetIndex < rowPageCount;
            }
            
            public String getTitle() {
                return String.valueOf(SimpleExportor.this.preSheetName) + (this.sheetIndex - 1);
            }
            
            public GridData getGridData() {
                final GridData gridData = SimpleExportor.this.reportData.getPagedGridData(this.sheetIndex);
                ++this.sheetIndex;
                return gridData;
            }
        };
        final BatchExportor batchExportor = new BatchExportor(gridIterator);
        batchExportor.setToSingleFile(true);
        try {
            batchExportor.Export(outStream);
        }
        catch (final ExcelException e) {
            throw e;
        }
        catch (final Exception e2) {
            e2.printStackTrace();
        }
        finally {
            this.reportData.setRowCountPerPage(oldRowCountPerPage);
            this.reportData.setScrollBottomRow(localBottomRow);
            this.reportData.setScrollTopRow(localTopRow);
        }
        this.reportData.setRowCountPerPage(oldRowCountPerPage);
        this.reportData.setScrollBottomRow(localBottomRow);
        this.reportData.setScrollTopRow(localTopRow);
    }
    
    public HashMap getHSSFFontMap() {
        return this.HSSFFontMap;
    }
    
    public void setHSSFFontMap(final HashMap hSSFFontMap) {
        this.HSSFFontMap = hSSFFontMap;
    }
    
    private Workbook createWorkbook(final int mode) {
        Workbook wb = null;
        if (mode == 0) {
            wb = (Workbook)new HSSFWorkbook();
        }
        else if (1 == mode) {
            wb = (Workbook)new XSSFWorkbook();
        }
        else {
            if (2 != mode) {
                throw new IllegalStateException("不支持导出excel模式");
            }
            wb = (Workbook)new SXSSFWorkbook();
        }
        return wb;
    }
}
